@@ -6,5 +6,5 @@ if (file.exists(nrdfile)) {
     ver <- as.package_version(gsub(".* ([0-9\\.]+) .*", "\\1", nrd[grepl("\\{Changes", nrd)]))
     dcf <- read.dcf(system.file("DESCRIPTION", package = pkg))
     cur <- as.package_version(dcf[[1,"Version"]])
-    if (cur != ver[1] && !isCI) stop("Expected NEWS entry for ", cur, " but saw ", ver[1], call. = FALSE)
+    if (cur != ver[1] && !isCI) stop("Expected NEWS entry for ", cur, " saw ", ver[1], call. = FALSE)
 }
